package de.fhdw.wtf.common.ast;

import de.fhdw.wtf.common.ast.visitor.AttributModifierVisitor;
import de.fhdw.wtf.common.ast.visitor.AttributeModifierVisitorReturn;
import de.fhdw.wtf.common.ast.visitor.AttributeModifierVisitorReturnException;
import de.fhdw.wtf.common.token.Token;

/**
 * This class represents a modifier of an {@link Attribute}. A modifier comes to effect at the code generation.
 * 
 */
public abstract class AttributeModifier extends SyntaxObject {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 7294206416348396019L;
	
	/**
	 * Protected Constructor of {@link AttributeModifier}.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @param lastToken
	 *            lastToken
	 */
	protected AttributeModifier(final Token firstToken, final Token lastToken) {
		super(firstToken, lastToken);
		
	}
	
	/**
	 * Accepts the sub types of {@link AttributeModifier} and implements the required functions.
	 * 
	 * @param visitor
	 *            is visitor that describes what has to be done for the particular {@link AttributeModifier}.
	 * @return Boolean
	 */
	public abstract boolean accept(AttributModifierVisitor visitor);
	
	/**
	 * Accepts a visitor with dynamic return type.
	 * 
	 * @param visitor
	 *            The Visitor to be accepted.
	 * @param <X>
	 *            ReturnType
	 * @return X.
	 */
	public abstract <X> X accept(AttributeModifierVisitorReturn<X> visitor);
	
	/**
	 * Accepts a visitor with dynamic return type and exception.
	 * 
	 * @param visitor
	 *            The Visitor to be accepted.
	 * @param <X>
	 *            ReturnType
	 * @param <Y>
	 *            ExceptionType
	 * @return X
	 * @throws Y
	 *             Exception
	 */
	public abstract <X, Y extends Exception> X accept(AttributeModifierVisitorReturnException<X, Y> visitor) throws Y;
	
}
