package de.fhdw.wtf.common.ast;

import de.fhdw.wtf.common.ast.visitor.ConstructorReferenceStateVisitor;
import de.fhdw.wtf.common.ast.visitor.ConstructorReferenceStateVisitorException;
import de.fhdw.wtf.common.ast.visitor.ConstructorReferenceStateVisitorReturn;
import de.fhdw.wtf.common.ast.visitor.ConstructorReferenceStateVisitorReturnException;

/**
 * This interface represents an abstract state of {@link ConstructorReference}.
 */
public interface ConstructorReferenceState {
	
	/**
	 * Accept-Method from Visitor-Pattern.
	 * 
	 * @param v
	 *            visitor
	 */
	void accept(ConstructorReferenceStateVisitor v);
	
	/**
	 * Accept-Method from Visitor-Pattern.
	 * 
	 * @param <X>
	 *            Returntype
	 * @param v
	 *            visitor
	 * @return X
	 */
	<X> X accept(ConstructorReferenceStateVisitorReturn<X> v);
	
	/**
	 * Accept-Method from Visitor-Pattern.
	 * 
	 * @param <Y>
	 *            ExceptionType
	 * @param v
	 *            visitor
	 * @throws Y
	 *             Exception
	 * 
	 */
	<Y extends Exception> void accept(ConstructorReferenceStateVisitorException<Y> v) throws Y;
	
	/**
	 * Accept-Method from Visitor-Pattern.
	 * 
	 * @param <X>
	 *            Returntype
	 * @param <Y>
	 *            ExceptionType
	 * @param v
	 *            visitor
	 * @return X
	 * @throws Y
	 *             Exception
	 */
	<X, Y extends Exception> X accept(ConstructorReferenceStateVisitorReturnException<X, Y> v) throws Y;
	
	@Override
	boolean equals(Object obj);
}
