package de.fhdw.wtf.common.ast;

import de.fhdw.wtf.common.ast.visitor.DatabaseIDStateVisitor;
import de.fhdw.wtf.common.ast.visitor.DatabaseIDStateVisitorReturn;
import de.fhdw.wtf.common.ast.visitor.DatabaseIDStateVisitorReturnException;

/**
 * In this State, the Database-ID is set.
 * 
 */
public class DatabaseIDSetState implements DatabaseIDState {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 3943532888453787057L;
	
	/**
	 * Database-ID.
	 */
	private final long dbId;
	
	/**
	 * A {@link DatabaseIDSetState} which have a ID.
	 * 
	 * @param typeId
	 *            typeId
	 */
	public DatabaseIDSetState(final long typeId) {
		this.dbId = typeId;
	}
	
	@Override
	public void accept(final DatabaseIDStateVisitor v) {
		v.handle(this);
		
	}
	
	/**
	 * Return the Database-ID.
	 * 
	 * @return Database-ID
	 */
	public long getDatabaseId() {
		return this.dbId;
	}
	
	@Override
	public <X> X accept(final DatabaseIDStateVisitorReturn<X> v) {
		return v.handle(this);
	}
	
	@Override
	public <X, Y extends Exception> X accept(final DatabaseIDStateVisitorReturnException<X, Y> v) throws Y {
		return v.handle(this);
	}
	
	@Override
	public long getId() {
		return this.getDatabaseId();
	}
}
