package de.fhdw.wtf.common.ast.type;

import de.fhdw.wtf.common.ast.visitor.ClassModifierVisitor;
import de.fhdw.wtf.common.ast.visitor.ClassModifierVisitorReturn;
import de.fhdw.wtf.common.token.Token;

/**
 * A concrete {@link ClassModifier}. A {@link ClassType} with this modifier will be generated as a service class.
 */
public final class ClassModifierService extends ClassModifier {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -1793433546323869367L;
	
	/**
	 * Constant to define hashCode().
	 */
	private static final int HASHCODE_CONSTANT = 293490;
	
	/**
	 * Constructor of {@link ClassModifierService}.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @param lastToken
	 *            lastToken
	 */
	private ClassModifierService(final Token firstToken, final Token lastToken) {
		super(firstToken, lastToken);
	}
	
	/**
	 * Creates a {@link ClassModifierService}-Object.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @param lastToken
	 *            lastToken
	 * @return The {@link ClassModifierService}-Object
	 */
	public static ClassModifierService create(final Token firstToken, final Token lastToken) {
		return new ClassModifierService(firstToken, lastToken);
	}
	
	/**
	 * Creates a {@link ClassModifierService}-Object.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @return The {@link ClassModifierService}-Object
	 */
	public static ClassModifierService create(final Token firstToken) {
		return new ClassModifierService(firstToken, null);
	}
	
	@Override
	public boolean equals(final Object o) {
		return o instanceof ClassModifierService;
	}
	
	@Override
	public int hashCode() {
		return HASHCODE_CONSTANT;
	}
	
	@Override
	public String toString() {
		return de.fhdw.wtf.common.constants.parser.AstDescriptionConstants.MODIFIER_SERVICE;
	}
	
	@Override
	public boolean accept(final ClassModifierVisitor visitor) {
		return visitor.handle(this);
	}
	
	@Override
	public <X> X accept(final ClassModifierVisitorReturn<X> visitor) {
		return visitor.handle(this);
	}
	
}
