package de.fhdw.wtf.common.ast.type;

import de.fhdw.wtf.common.ast.visitor.ClassModifierVisitor;
import de.fhdw.wtf.common.ast.visitor.ClassModifierVisitorReturn;
import de.fhdw.wtf.common.token.Token;

/**
 * A concrete {@link ClassModifier}. A {@link ClassType} with this modifier will be generated as a transient class.
 */
public final class ClassModifierTransient extends ClassModifier {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 9149195615801922290L;
	
	/**
	 * Constant to define hashCode().
	 */
	private static final int HASHCODE_CONSTANT = 8934798;
	
	/**
	 * Constructor of {@link ClassModifierTransient}.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @param lastToken
	 *            lastToken
	 */
	private ClassModifierTransient(final Token firstToken, final Token lastToken) {
		super(firstToken, lastToken);
	}
	
	/**
	 * Creates a {@link ClassModifierTransient}-Object.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @param lastToken
	 *            lastToken
	 * @return The {@link ClassModifierTransient}-Object
	 */
	public static ClassModifierTransient create(final Token firstToken, final Token lastToken) {
		return new ClassModifierTransient(firstToken, lastToken);
	}
	
	/**
	 * Creates a {@link ClassModifierTransient}-Object.
	 * 
	 * @param firstToken
	 *            firstToken
	 * @return The {@link ClassModifierTransient}-Object
	 */
	public static ClassModifierTransient create(final Token firstToken) {
		return new ClassModifierTransient(firstToken, null);
	}
	
	@Override
	public boolean equals(final Object o) {
		return o instanceof ClassModifierTransient;
	}
	
	@Override
	public int hashCode() {
		return HASHCODE_CONSTANT;
	}
	
	@Override
	public String toString() {
		return de.fhdw.wtf.common.constants.parser.AstDescriptionConstants.MODIFIER_TRANSIENT;
	}
	
	@Override
	public boolean accept(final ClassModifierVisitor visitor) {
		return visitor.handle(this);
	}
	
	@Override
	public <X> X accept(final ClassModifierVisitorReturn<X> visitor) {
		return visitor.handle(this);
	}
	
}
