package de.fhdw.wtf.common.ast.type;

import java.util.List;

import de.fhdw.wtf.common.ast.DatabaseIDNotSetState;
import de.fhdw.wtf.common.ast.DatabaseIDState;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents a non-proxy type. A real type can store a database ID.
 */
public abstract class RealType extends Type {
	
	/**
	 * Holds the database type id, if available.
	 */
	private DatabaseIDState typeId;
	
	/**
	 * Creates a {@link RealType}.
	 * 
	 * @param firstToken
	 *            The token starting the type definition.
	 * @param lastToken
	 *            The first token after the type definition.
	 */
	protected RealType(final Token firstToken, final Token lastToken) {
		super(firstToken, lastToken);
		this.typeId = new DatabaseIDNotSetState();
	}
	
	/**
	 * Creates a {@link RealType}.
	 * 
	 * @param firstToken
	 *            The token starting the type definition.
	 * @param lastToken
	 *            The first token after the type definition.
	 * @param superTypes
	 *            A collection of super types.
	 */
	protected RealType(final Token firstToken, final Token lastToken, final List<Type> superTypes) {
		super(firstToken, lastToken, superTypes);
		this.typeId = new DatabaseIDNotSetState();
	}
	
	@Override
	public DatabaseIDState getTypeId() {
		return this.typeId;
	}
	
	@Override
	public void setTypeId(final DatabaseIDState typeId) {
		this.typeId = typeId;
	}
	
}
