package de.fhdw.wtf.common.ast.visitor;

import de.fhdw.wtf.common.ast.type.ListType;
import de.fhdw.wtf.common.ast.type.MapType;
import de.fhdw.wtf.common.ast.type.ProductType;
import de.fhdw.wtf.common.ast.type.SumType;
import de.fhdw.wtf.common.ast.type.ThrownType;

/**
 * Return-Visitor for {@link de.fhdw.wtf.common.ast.type.CompositeType}.
 * 
 * @param <X>
 *            ReturnType.
 */
public interface CompositeTypeVisitorReturn<X> {
	
	/**
	 * Handle-Method.
	 * 
	 * @param list
	 *            {@link ListType}
	 * @return X
	 */
	X handle(ListType list);
	
	/**
	 * Handle-Method.
	 * 
	 * @param map
	 *            {@link MapType}
	 * @return X
	 */
	X handle(MapType map);
	
	/**
	 * Handle-Method.
	 * 
	 * @param product
	 *            {@link ProductType}
	 * @return X
	 */
	X handle(ProductType product);
	
	/**
	 * Handle-Method.
	 * 
	 * @param sum
	 *            {@link SumType}
	 * @return X
	 */
	X handle(SumType sum);
	
	/**
	 * Handle-Method for a {@link ThrownType}-Object.
	 * 
	 * @param thrownType
	 *            the checked object
	 * @return X
	 */
	X handle(ThrownType thrownType);
}
