package de.fhdw.wtf.common.ast.visitor;

import de.fhdw.wtf.common.ast.type.ListType;
import de.fhdw.wtf.common.ast.type.MapType;
import de.fhdw.wtf.common.ast.type.ProductType;
import de.fhdw.wtf.common.ast.type.SumType;
import de.fhdw.wtf.common.ast.type.ThrownType;

/**
 * Return-Exception-Visitor for {@link de.fhdw.wtf.common.ast.type.CompositeType}.
 * 
 * @param <X>
 *            ReturnType.
 * @param <Y>
 *            ExceptionType
 */
public interface CompositeTypeVisitorReturnException<X, Y extends Exception> {
	
	/**
	 * Handle-Method.
	 * 
	 * @param list
	 *            {@link ListType}
	 * @return X
	 * @throws Y
	 *             Y
	 */
	X handle(ListType list) throws Y;
	
	/**
	 * Handle-Method.
	 * 
	 * @param map
	 *            {@link MapType}
	 * @return X
	 * @throws Y
	 *             Y
	 */
	X handle(MapType map) throws Y;
	
	/**
	 * Handle-Method.
	 * 
	 * @param product
	 *            {@link ProductType}
	 * @return X
	 * @throws Y
	 *             Y
	 */
	X handle(ProductType product) throws Y;
	
	/**
	 * Handle-Method.
	 * 
	 * @param sum
	 *            {@link SumType}
	 * @return X
	 * @throws Y
	 *             Y
	 */
	X handle(SumType sum) throws Y;
	
	/**
	 * Handle-Method for a {@link ThrownType}-Object.
	 * 
	 * @param thrownType
	 *            the checked object
	 * @return X
	 * @throws Y
	 *             Y
	 */
	X handle(ThrownType thrownType) throws Y;
}
