package de.fhdw.wtf.common.exception.walker;

import de.fhdw.wtf.common.ast.AttributeModifier;
import de.fhdw.wtf.common.exception.editor.EditorMarkable;
import de.fhdw.wtf.common.exception.editor.EditorMarker;
import de.fhdw.wtf.common.token.Position;

public final class InvalidAttributeModifierException extends TaskException implements EditorMarkable {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -3428993073389520999L;
	private final AttributeModifier attributeModifier;
	
	private InvalidAttributeModifierException(final AttributeModifier attributeModifier, final String reason) {
		super(de.fhdw.wtf.common.constants.walker.ExceptionConstants.INVALID_ATTRIBUTE_MODIFIER_MESSAGE + reason);
		this.attributeModifier = attributeModifier;
	}
	
	public static InvalidAttributeModifierException create(final AttributeModifier attributeModifier,
			final String reason) {
		return new InvalidAttributeModifierException(attributeModifier, reason);
	}
	
	@Override
	public Position getStartPosition() {
		return this.attributeModifier.getFirstToken().getPosition();
	}
	
	@Override
	public String getDescription() {
		return this.getMessage();
	}
	
	@Override
	public Position getEndPos() {
		return this.attributeModifier.getLastToken().getPosition();
	}
	
	@Override
	public EditorMarker getMarker() {
		return EditorMarker.INVALID_ATTRIBUTE_MODIFIER_MARKER;
	}
}
