package de.fhdw.wtf.common.exception.walker;

import de.fhdw.wtf.common.ast.ConstructorReference;
import de.fhdw.wtf.common.constants.walker.ExceptionConstants;

/**
 * Represents existence of an invalid {@link ConstructorReference} instance.
 */
public final class InvalidConstructorReferenceException extends EditorMarkableConstructorException {
	
	/**
	 * Instantiates a {@link InvalidConstructorReferenceException}.
	 * 
	 * @param constructorReference
	 *            the constructor reference which is invalid.
	 * @param message
	 *            a matching exception message preferable from the {@link ExceptionConstants}.
	 * 
	 */
	private InvalidConstructorReferenceException(final ConstructorReference constructorReference, final String message) {
		super(constructorReference, message + constructorReference.toString());
	}
	
	/**
	 * Instantiates a {@link InvalidConstructorReferenceException}.
	 * 
	 * @param constructorReference
	 *            the constructor reference which is invalid.
	 * @param message
	 *            a matching exception message preferable from the {@link ExceptionConstants}.
	 * @return an instance of {@link InvalidConstructorReferenceException}.
	 * 
	 */
	public static InvalidConstructorReferenceException create(final ConstructorReference constructorReference,
			final String message) {
		return new InvalidConstructorReferenceException(constructorReference, message);
	}
}
