package de.fhdw.wtf.common.token;

/**
 * A multi char token represents a scanned part of the input grammar. Each token-type defines a regular sequence of
 * characters belonging to its type.
 * 
 * This type is the interface describing variable tokens.
 */
public abstract class MultiCharToken extends Token {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -7790580991639162261L;
	
	/**
	 * String-Represantation of the Token.
	 * 
	 */
	private final String tokenString;
	
	/**
	 * Constructor initializing the position of this token.
	 * 
	 * @param tokenString
	 *            initial token String
	 * @param position
	 *            begin position of this token
	 */
	protected MultiCharToken(final String tokenString, final Position position) {
		super(position);
		this.tokenString = tokenString;
	}
	
	@Override
	public int getLength() {
		return this.getTokenString().length();
	}
	
	/**
	 * Getter for the token string.
	 * 
	 * @return token string
	 */
	public String getTokenString() {
		return this.tokenString;
	}
	
	@Override
	public String stringRepresentation() {
		return this.getTokenString();
	}
}
