package de.fhdw.wtf.common.token.keywords;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the class as a token in WTF.
 */
public final class ClassToken extends KeywordToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = 550670938084569881L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 463283;
	
	/**
	 * Defines constant "class" for {@link ClassToken}.
	 */
	private static final String TEXTUAL_REPRESENTATION = "class";
	
	/**
	 * Private constructor for {@link ClassToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of an {@link ClassToken} in the original input.
	 */
	private ClassToken(final Position position) {
		super(position);
	}
	
	/**
	 * Factory method for {@link ClassToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link KeywordToken} in the original input.
	 * @return a new instance of this {@link KeywordToken}.
	 */
	public static ClassToken create(final Position position) {
		return new ClassToken(position);
	}
	
	@Override
	public boolean isClassToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isClassToken();
	}
	
	@Override
	public int getLength() {
		return ClassToken.TEXTUAL_REPRESENTATION.length();
	}
	
	@Override
	public String stringRepresentation() {
		return TEXTUAL_REPRESENTATION;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
