package de.fhdw.wtf.common.token.keywords;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the group as a token in WTF.
 */
public final class GroupToken extends KeywordToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -7117064611926224898L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 7463423;
	
	/**
	 * Defines constant "group" for {@link GroupToken}.
	 */
	private static final String TEXTUAL_REPRESENTATION = "group";
	
	/**
	 * Private constructor for {@link GroupToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of an group token in the original input.
	 */
	private GroupToken(final Position position) {
		super(position);
	}
	
	/**
	 * Factory method for {@link GroupToken}.
	 * 
	 * @param position
	 *            represents the start position of this keyword token in the original input.
	 * @return a new instance of this keyword token.
	 */
	public static GroupToken create(final Position position) {
		return new GroupToken(position);
	}
	
	@Override
	public boolean isGroupToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isGroupToken();
	}
	
	@Override
	public int getLength() {
		return GroupToken.TEXTUAL_REPRESENTATION.length();
	}
	
	@Override
	public String stringRepresentation() {
		return TEXTUAL_REPRESENTATION;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
