package de.fhdw.wtf.common.token.keywords;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the "prior"-modifier as a token in WTF.
 */
public final class PriorToken extends AttributeModifierToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -5054918373745365413L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 121212;
	
	/**
	 * Defines constant "prior" for {@link PriorToken}.
	 */
	private static final String TEXTUAL_REPRESENTATION = "prior";
	
	/**
	 * Private constructor for {@link PriorToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the {@link AttributeModifierToken} <prior> in the original input.
	 */
	private PriorToken(final Position position) {
		super(position);
	}
	
	/**
	 * Factory method for {@link PriorToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link AttributeModifierToken} in the original input.
	 * @return a new instance of this {@link AttributeModifierToken}.
	 */
	public static PriorToken create(final Position position) {
		return new PriorToken(position);
	}
	
	@Override
	public boolean isPriorModifierToken() {
		return true;
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isPriorModifierToken();
	}
	
	@Override
	public int getLength() {
		return PriorToken.TEXTUAL_REPRESENTATION.length();
	}
	
	@Override
	public String stringRepresentation() {
		return TEXTUAL_REPRESENTATION;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
}
