package de.fhdw.wtf.common.token.keywords;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the "service"-modifier as a token in WTF.
 */
public final class ServiceToken extends ClassModifierToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -2986655846111440741L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 6923497;
	
	/**
	 * Defines constant "service" for {@link ServiceToken}.
	 */
	private static final String TEXTUAL_REPRESENTATION = "service";
	
	/**
	 * Private constructor for {@link ServiceToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the {@link ClassModifierToken} <service> in the original input.
	 */
	private ServiceToken(final Position position) {
		super(position);
	}
	
	/**
	 * Factory method for {@link ServiceToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link ClassModifierToken} in the original input.
	 * @return a new instance of this {@link ClassModifierToken}.
	 */
	public static ServiceToken create(final Position position) {
		return new ServiceToken(position);
	}
	
	@Override
	public int getLength() {
		return ServiceToken.TEXTUAL_REPRESENTATION.length();
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isServiceToken();
	}
	
	@Override
	public String stringRepresentation() {
		return ServiceToken.TEXTUAL_REPRESENTATION;
	}
	
	@Override
	public boolean isServiceToken() {
		return true;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
	
}
