package de.fhdw.wtf.common.token.symbols;

import de.fhdw.wtf.common.token.Position;
import de.fhdw.wtf.common.token.Token;

/**
 * Represents the double square bracket open symbol '[[' as a token.
 */
public final class DoubleSquareBracketOpenToken extends SymbolToken {
	
	/**
	 * generated.
	 */
	private static final long serialVersionUID = -3107058962840662439L;
	
	/**
	 * Defines constant for hashCodeTemplate().
	 */
	private static final int HASHCODE_TEMPLATE_CONSTANT = 563476;
	
	/**
	 * Private constructor for {@link DoubleSquareBracketOpenToken}. Use create(...)-Factory instead!
	 * 
	 * @param position
	 *            represents the start position of the symbol '[[' in the original input.
	 */
	private DoubleSquareBracketOpenToken(final Position position) {
		super(position, SymbolConstants.DOUBLESQUAREBRACKETOPEN);
	}
	
	/**
	 * Factory method for {@link DoubleSquareBracketOpenToken}.
	 * 
	 * @param position
	 *            represents the start position of this {@link SymbolToken} in the original input.
	 * @return a new instance of this {@link SymbolToken}.
	 */
	public static DoubleSquareBracketOpenToken create(final Position position) {
		return new DoubleSquareBracketOpenToken(position);
	}
	
	@Override
	protected boolean equalsTemplate(final Token t) {
		return t.isDoubleSquareBracketOpenToken();
	}
	
	@Override
	public String stringRepresentation() {
		return SymbolConstants.DOUBLESQUAREBRACKETOPEN;
	}
	
	@Override
	public boolean isDoubleSquareBracketOpenToken() {
		return true;
	}
	
	@Override
	protected int hashCodeTemplate() {
		return HASHCODE_TEMPLATE_CONSTANT;
	}
	
}
