package de.fhdw.wtf.dsl.scanner.common;

import de.fhdw.wtf.common.token.Position;

/**
 * {@link Delta} were the next {@link ScannerState} is created via {@link StateCreater}.
 * 
 * @see Delta
 */
public class CreatingDelta extends Delta {
	
	/**
	 * Next {@link StateCreater}.
	 */
	private final StateCreater nextStateCreater;
	
	/**
	 * Constructor of {@link CreatingDelta}.
	 * 
	 * @param fromStateMatcher
	 *            fromStateMatcher
	 * @param inputMatcher
	 *            inputMatcher
	 * @param nextStateCreater
	 *            nextStateCreater
	 */
	public CreatingDelta(final StateMatcher fromStateMatcher,
			final InputMatcher inputMatcher,
			final StateCreater nextStateCreater) {
		super(fromStateMatcher, inputMatcher);
		this.nextStateCreater = nextStateCreater;
	}
	
	/**
	 * Returns the next {@link StateCreater}.
	 * 
	 * @return next {@link StateCreater}
	 */
	public StateCreater getNextStateCreater() {
		return this.nextStateCreater;
	}
	
	@Override
	public ScannerState getNextScannerState(final Position position, final ScannerState currentState) {
		return this.getNextStateCreater().create(position);
	}
	
	/**
	 * Factory-Method for {@link CreatingDelta}.
	 * 
	 * @param fromStateMatcher
	 *            fromStateMatcher
	 * @param inputMatcher
	 *            inputMatcher
	 * @param nextStateCreater
	 *            nextStateCreater
	 * @return The {@link CreatingDelta}-Object.
	 */
	public static CreatingDelta create(final StateMatcher fromStateMatcher,
			final InputMatcher inputMatcher,
			final StateCreater nextStateCreater) {
		return new CreatingDelta(fromStateMatcher, inputMatcher, nextStateCreater);
	}
}
