package de.fhdw.wtf.parser;

import java.util.Collection;

import de.fhdw.wtf.common.ast.type.ProductElementType;
import de.fhdw.wtf.common.ast.type.Type;
import de.fhdw.wtf.common.exception.parser.AbstractParserException;
import de.fhdw.wtf.common.stream.TokenStream;
import de.fhdw.wtf.common.token.IdentifierToken;

/**
 * Parses tokens to {@link ProductElementType}.
 */
final class ParameterParser {
	
	/**
	 * TokenStream.
	 */
	private final TokenStream stream;
	
	/**
	 * Collection of exceptions.
	 */
	private final Collection<AbstractParserException> exceptions;
	
	/**
	 * Constructor of {@link ParameterParser}.
	 * 
	 * @param stream
	 *            tokenStream
	 * @param exceptions
	 *            collection of exceptions
	 */
	private ParameterParser(final TokenStream stream, final Collection<AbstractParserException> exceptions) {
		this.stream = stream;
		this.exceptions = exceptions;
	}
	
	/**
	 * FactoryMethod for {@link ParameterParser}.
	 * 
	 * @param stream
	 *            tokenStream
	 * @param exceptions
	 *            collection of exceptions
	 * @return The {@link ParameterParser}-Object.
	 */
	static ParameterParser create(final TokenStream stream, final Collection<AbstractParserException> exceptions) {
		return new ParameterParser(stream, exceptions);
	}
	
	/**
	 * Parses the next series of Token of this.stream to {@link ProductElementType}.
	 * 
	 * @return ProductElementType
	 * @throws AbstractParserException
	 *             AbstractParserException
	 */
	ProductElementType parse() throws AbstractParserException {
		final IdentifierToken identiferToken = ParserUtils.requireAndRemoveIdentifier(this.stream);
		ParserUtils.requireAndRemoveColonToken(this.stream);
		final Type type = TypeParser.create(this.stream, this.exceptions).parse();
		final ProductElementType param =
				ProductElementType.create(
						identiferToken.stringRepresentation(),
						type,
						identiferToken,
						this.stream.peek());
		return param;
	}
}
