package de.fhdw.wtf.walker.tasks;

import java.util.ArrayList;
import java.util.Collection;

import de.fhdw.wtf.common.ast.Attribute;
import de.fhdw.wtf.common.ast.ConstructorOrOperation;
import de.fhdw.wtf.common.ast.Group;
import de.fhdw.wtf.common.ast.Model;
import de.fhdw.wtf.common.ast.Name;
import de.fhdw.wtf.common.ast.type.ClassType;
import de.fhdw.wtf.common.exception.walker.DoubleGroupcomponentException;
import de.fhdw.wtf.common.exception.walker.TaskException;
import de.fhdw.wtf.common.task.TaskExecutor;
import de.fhdw.wtf.walker.walker.SimpleWalkerTask;

/**
 * This Task check the Classnames and Groupnames. If there are duplicate Name of Classes or Groups and Classes and
 * Groups are named equal, this Checker will thrown an {@link DoubleGroupcomponentException} .
 * 
 * This Checker must run before the {@link TypeReferencer}.
 */
public final class DoubleGroupcomponentCheck extends SimpleWalkerTask {
	
	/**
	 * List of already found groupcomponents.
	 */
	private final Collection<Name> groupcomponents;
	
	/**
	 * Constructor of {@link DoubleGroupcomponentCheck}.
	 * 
	 * @param m
	 *            model
	 * @param taskmanager
	 *            taskmanager
	 */
	private DoubleGroupcomponentCheck(final Model m, final TaskExecutor taskmanager) {
		super(m, taskmanager);
		this.groupcomponents = new ArrayList<>();
	}
	
	/**
	 * Creates a {@link DoubleGroupcomponentCheck}-Object.
	 * 
	 * @param m
	 *            model
	 * @param taskmanager
	 *            taskmanager
	 * @return The {@link DoubleGroupcomponentCheck}-Object.
	 */
	public static DoubleGroupcomponentCheck create(final Model m, final TaskExecutor taskmanager) {
		return new DoubleGroupcomponentCheck(m, taskmanager);
	}
	
	@Override
	public void handleGroup(final Group g) throws TaskException {
		if (this.groupcomponents.contains(g.getName())) {
			throw DoubleGroupcomponentException.create(g.getName().toString());
		}
		this.groupcomponents.add(g.getName());
	}
	
	@Override
	public void handleClass(final ClassType c) throws TaskException {
		if (this.groupcomponents.contains(c.getTypeName())) {
			throw DoubleGroupcomponentException.create(c.getTypeName().toString());
		}
		this.groupcomponents.add(c.getTypeName());
	}
	
	@Override
	public void handleAttribute(final Attribute a, final ClassType owner) throws TaskException {
		// Nothing to do here
	}
	
	@Override
	public void finalizeTask() throws TaskException {
		// Nothing to do here
	}
	
	@Override
	public void beginTask() throws TaskException {
		// Nothing to do here
	}
	
	@Override
	public void handleConstructorOrOperation(final ConstructorOrOperation coo, final ClassType owner)
			throws TaskException {
		// Nothing to do here
		
	}
}
